@@ -17,15 +17,16 @@ local cli = require "cliargs"
 
 cli:set_name("example.lua")
 
-cli:optarg("OUTPUT", "Path to where the combined HTML output should be saved.", "./a.html")
+cli:splat("OUTPUT", "Path to where the combined HTML output should be saved.", "./a.html")
 
-cli:add_option("-i URLs...", "A url to download. You can pass in as many as needed", {} --[[ this is the important bit! ]])
-cli:add_option("-j THREADS", "Concurrency threshold; the higher the number, the more files will be downloaded in parallel.", "2")
+cli:option("-i URLs...", "A url to download. You can pass in as many as needed", {} --[[ this is the important bit! ]])
+cli:option("-j THREADS", "Concurrency threshold; the higher the number, the more files will be downloaded in parallel.", "2")
 
 -- Parses from _G['arg']
-local args = cli:parse_args()
+local args, err = cli:parse()
 
-if not args then
+if not args and err then
+  print(err)
   os.exit(1) -- something wrong happened and an error was printed
 end
 
