@@ -7,20 +7,20 @@ describe("utils::wordwrap", function()
     local expected, result
 
     result = subject(text, 10)
-    expected = "123456789\n123456789\n123456789!"
+    expected = { "123456789", "123456789", "123456789!" }
     assert.is.same(result, expected)
 
     -- exact length + 1 overflow
     result = subject(text, 9)
-    expected = "123456789\n123456789\n123456789\n!"
+    expected = { "123456789", "123456789", "123456789", "!" }
     assert.is.same(result, expected)
 
-    result = subject(text, 9, nil, true)
-    expected = "123456789\n123456789\n123456789!"
+    result = subject(text, 9, true)
+    expected = { "123456789", "123456789", "123456789!" }
     assert.is.same(result, expected)
 
     result = subject(text, 8)
-    expected = "12345678\n9\n12345678\n9\n12345678\n9!"
+    expected = { "12345678", "9", "12345678", "9", "12345678", "9!" }
     assert.is.same(result, expected)
   end)
 end)
